@@ -7,6 +7,8 @@ from ..dataframes import DataFrames, get_dataframe_format
 from .linear import LinearFunction_C, DictOfLinearFunction_C
 from ..general_precision import l4_float_dtype
 from .constraints import ParametricConstraintList
+from .tree import NestingTree
+from .abstract_model import AbstractChoiceModel
 from typing import Sequence, Mapping
 from numbers import Number
 import numpy as np
@@ -48,58 +50,84 @@ class Model(_Model5c):
 	"""
 
 	utility_co = DictOfLinearFunction_C()
-	"""DictOfLinearFunction_C : The portion of the utility function computed from idco data.
-	
+	"""DictOfLinearFunction_C : The portion of the utility function computed from |idco| data.
+
 	The keys of this mapping are alternative codes for the applicable elemental
 	alteratives, and the values are linear functions to compute for the indicated
 	alternative.  Each alternative that has any idco utility components must have
 	a unique linear function given.
+
+	Examples
+	--------
+
+	>>> from larch import Model, P, X
+	>>> m = Model()
+	>>> m.utility_co = {
+	... 	1: P.ParamA1 * X.DataA,
+	... 	2: P.ParamA2 * X.DataA + P.ParamASC2,
+	... }
+	>>> print(m.utility_co)
+	DictOfLinearFunction_C({1: P.ParamA1 * X.DataA, 2: P.ParamA2 * X.DataA + P.ParamASC2})
 	"""
 
 	utility_ca = LinearFunction_C()
-	"""LinearFunction_C : The portion of the utility function computed from idca data.
-	
+	"""LinearFunction_C : The portion of the utility function computed from |idca| data.
+
+	Data expressions in this utility function can actually reference both |idca|
+	and |idco| format variables. Except in unusual model designs, every complete data
+	expression should have at least one |idca| component.
+
 	Examples
 	--------
-		
+
 	>>> from larch import Model, P, X
 	>>> m = Model()
 	>>> m.utility_ca = P.Param1 * X.Data1 + P.Param2 * X.Data2
 	>>> print(m.utility_ca)
 	P.Param1 * X.Data1 + P.Param2 * X.Data2
-	
+	>>> m.utility_ca += P.Param3 * X.Data3 / X.DataCO4
+	>>> print(m.utility_ca)
+	P.Param1 * X.Data1 + P.Param2 * X.Data2 + P.Param3 * X('Data3/DataCO4')
 	"""
 
 	quantity_ca = LinearFunction_C()
-	"""LinearFunction_C : The portion of the quantity function computed from idca data.
-	
+	"""LinearFunction_C : The portion of the quantity function computed from |idca| data.
+
+	Data expressions in this utility function can actually reference both |idca|
+	and |idco| format variables. Except in unusual model designs, every complete data
+	expression should have at least one |idca| component.
+
 	Note that for the quantity function, the actual computed linear function
-	uses the exponential of the parameter value(s), not the raw values. Thus, 
+	uses the exponential of the parameter value(s), not the raw values. Thus,
 	if the quantity function is given as `P.Param1 * X.Data1 + P.Param2 * X.Data2`,
 	the computed values will actually be `exp(P.Param1) * X.Data1 + exp(P.Param2) * X.Data2`.
-	This transformation ensures that the outcome from the quantity function is 
+	This transformation ensures that the outcome from the quantity function is
 	always positive, so long as at all of the data terms in the function are
 	positive.  The `LinearFunction_C` class itself is not intrinsically aware
-	of this implementation detail, but the `Model.utility_functions()` method is, 
+	of this implementation detail, but the `Model.utility_functions()` method is,
 	and will render the complete utility function in a mathematically correct form.
-	
+
 	Examples
 	--------
-		
+
 	>>> from larch import Model, P, X
 	>>> m = Model()
 	>>> m.quantity_ca = P.Param1 * X.Data1 + P.Param2 * X.Data2
 	>>> print(m.quantity_ca)
 	P.Param1 * X.Data1 + P.Param2 * X.Data2
-
+	>>> m.quantity_ca += P.Param3 * X.Data3 / X.DataCO4
+	>>> print(m.quantity_ca)
+	P.Param1 * X.Data1 + P.Param2 * X.Data2 + P.Param3 * X('Data3/DataCO4')
 	"""
 
+	_graph = NestingTree()
+
 	constraints = ParametricConstraintList()
 
 	@classmethod
-	def Example(cls, n=1):
+	def Example(cls, n=1, legacy=False):
 		from ..examples import example
-		return example(n)
+		return example(n, legacy=legacy)
 
 	@classmethod
 	def load(cls, filename):
@@ -113,19 +141,35 @@ class Model(_Model5c):
 		import pickle
 		return pickle.load(filename)
 
-	def __init__(self,
-				 utility_ca=None,
-				 utility_co=None,
-				 quantity_ca=None,
-				 constraints=None,
-				 **kwargs):
-		import sys
+	def __init__(
+			self,
+			*args,
+			model=None,
+			dataservice=None,
+			utility_ca=None,
+			utility_co=None,
+			quantity_ca=None,
+			constraints=None,
+			**kwargs,
+	):
 		self._sklearn_data_format = 'idce'
+		for a in args:
+			if model is None and isinstance(a, Model):
+				model = a
+			if dataservice is None and isinstance(a, DataFrames):
+				dataservice = a
 		self.utility_co = utility_co
 		self.utility_ca = utility_ca
 		self.quantity_ca = quantity_ca
 		self.constraints = constraints
 		super().__init__(**kwargs)
+		if model is not None:
+			self.__setstate__(model.__getstate__())
+			if dataservice is None:
+				self.dataservice = model.dataservice
+			self.dataframes = model.dataframes
+		if dataservice is not None:
+			self.dataservice = dataservice
 		self._scan_all_ensure_names()
 		self.mangle()
 
@@ -391,7 +435,8 @@ class Model(_Model5c):
 
 
 	def __repr__(self):
-		s = "<larch.Model"
+		s = "<larch."
+		s += self.__class__.__name__
 		if self.is_mnl():
 			s += " (MNL)"
 		else:
@@ -680,7 +725,7 @@ class Model(_Model5c):
 	):
 		self.unmangle(True)
 		from ..troubleshooting import doctor
-		return doctor(
+		result = doctor(
 			self,
 			repair_ch_av=repair_ch_av,
 			repair_ch_zq=repair_ch_zq,
@@ -690,6 +735,10 @@ class Model(_Model5c):
 			repair_nan_data_co=repair_nan_data_co,
 			verbose=verbose,
 		)
+		if repair_ch_av or repair_ch_zq or repair_asc or repair_noch_nowt \
+				or repair_nan_wt or repair_nan_data_co:
+			self.mangle()
+		return result
 
 	def copy(self):
 		"""
@@ -706,12 +755,17 @@ class Model(_Model5c):
 		import pickle
 		result = pickle.loads(self.dumps())
 		result.dataservice = self.dataservice
-		result.graph.set_touch_callback(result.mangle)
+		result._graph = result.graph
 		return result
 
-	def remove_unused_parameters(self):
+	def remove_unused_parameters(self, verbose=True):
 		"""
 		Remove parameters that are not used in the model.
+
+		Parameters
+		----------
+		verbose : bool, default True
+			Generate log messages about how many parameters were dropped.
 		"""
 		self.unmangle(True)
 		old_pf = self.pf.copy()
@@ -721,8 +775,14 @@ class Model(_Model5c):
 		for col in overlay.columns:
 			f = ~overlay[col].isna()
 			self.pf.loc[f, col] = overlay.loc[f, col]
-
-
+		if verbose:
+			dropped_params = [p for p in old_pf.index if p not in self.pf.index]
+			if len(dropped_params) == 0:
+				pass
+			elif len(dropped_params) < 4:
+				logger.warning(f"dropped {len(dropped_params)} parameters: {', '.join(dropped_params)}")
+			else:
+				logger.warning(f"dropped {len(dropped_params)} parameters including: {', '.join(dropped_params[:3])}")
 
 	def data_statistics(self):
 		"""
@@ -848,4 +908,3 @@ class Model(_Model5c):
 				binding_constraints.append(c)
 
 		return binding_constraints
-
